LinearProgressPageIndicator class

Inheritance

Constructors

LinearProgressPageIndicator({Key? key, required ValueNotifier<int> currentPageNotifier, required double width, required double height, required int itemCount, required Color progressColor, Color? backgroundColor, Duration duration = const Duration(milliseconds: 200)})
const

Properties

backgroundColor → Color?
The background color of the indicator
final
currentPageNotifier → ValueNotifier<int>
The current page index ValueNotifier
final
duration → Duration
The duration of the progress animation
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of indicator
final
itemCount → int
The number of pages
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
progressColor → Color
The progress color of the indicator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The width of indicator
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _LinearProgressPageIndicatorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited