StepPageIndicator class

Inheritance

Constructors

StepPageIndicator({Key? key, required ValueNotifier<int> currentPageNotifier, required int itemCount, ValueChanged<int>? onPageSelected, double size = _defaultSize, double stepSpacing = _defaultSpacing, Color? stepColor, Widget? previousStep, Widget? selectedStep, Widget? nextStep})

Properties

currentPageNotifier → ValueNotifier<int>
The current page index ValueNotifier
final
hashCode → int
The hash code for this object.
no setterinherited
itemCount → int
The number of items managed by the PageController
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nextStep → Widget?
The step display widget for the next steps
final
onPageSelected → ValueChanged<int>?
Called when a step is tapped
final
previousStep → Widget?
The step display widget for the previous steps
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedStep → Widget?
The step display widget for the selected step
final
size → double
The step size
final
stepColor → Color
The step color
final
stepSpacing → double
The space between steps
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _StepPageIndicatorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited